@@ -31,15 +31,22 @@ class Auth:
             if url.scheme == 'https':
                 query.extend({'api_key': key, 'timestamp': expires})
                 query_string = '&'.join(f'{k}={v}' for k, v in sorted(query.items()))
-                sign = hmac.new(secret, query_string.encode(), hashlib.sha256).hexdigest()
+                sign = hmac.new(
+                    secret, query_string.encode(), hashlib.sha256
+                ).hexdigest()
                 query.extend({'sign': sign})
             else:
                 expires = str(int((time.time() + 1.0) * 1000))
                 path = f'{method}/realtime{expires}'
                 signature = hmac.new(secret, path.encode(), hashlib.sha256).hexdigest()
-                query.extend({'api_key': key, 'expires': expires, 'signature': signature})
+                query.extend(
+                    {'api_key': key, 'expires': expires, 'signature': signature}
+                )
             url = url.with_query(query)
-            args = (method, url, )
+            args = (
+                method,
+                url,
+            )
         else:
             data.update({'api_key': key, 'timestamp': expires})
             body = FormData(sorted(data.items()))()
@@ -50,27 +57,6 @@ class Auth:
 
         return args
 
-    @staticmethod
-    def btcmex(args: Tuple[str, URL], kwargs: Dict[str, Any]) -> Tuple[str, URL]:
-        method: str = args[0]
-        url: URL = args[1]
-        data: Dict[str, Any] = kwargs['data'] or {}
-        headers: CIMultiDict = kwargs['headers']
-
-        session: aiohttp.ClientSession = kwargs['session']
-        key: str = session.__dict__['_apis'][Hosts.items[url.host].name][0]
-        secret: bytes = session.__dict__['_apis'][Hosts.items[url.host].name][1]
-
-        path = url.raw_path_qs if url.scheme == 'https' else '/api/v1/signature'
-        body = FormData(data)()
-        expires = str(int(time.time() + 5.0))
-        message = f'{method}{path}{expires}'.encode() + body._value
-        signature = hmac.new(secret, message, hashlib.sha256).hexdigest()
-        kwargs.update({'data': body})
-        headers.update({'api-expires': expires, 'api-key': key, 'api-signature': signature})
-
-        return args
-
     @staticmethod
     def binance(args: Tuple[str, URL], kwargs: Dict[str, Any]) -> Tuple[str, URL]:
         method: str = args[0]
@@ -88,10 +74,15 @@ class Auth:
                 query = MultiDict(url.query)
                 query.extend({'timestamp': expires})
                 query_string = '&'.join(f'{k}={v}' for k, v in query.items())
-                signature = hmac.new(secret, query_string.encode(), hashlib.sha256).hexdigest()
+                signature = hmac.new(
+                    secret, query_string.encode(), hashlib.sha256
+                ).hexdigest()
                 query.extend({'signature': signature})
                 url = url.with_query(query)
-                args = (method, url, )
+                args = (
+                    method,
+                    url,
+                )
         else:
             data.update({'timestamp': expires})
             body = FormData(data)()
@@ -120,7 +111,9 @@ class Auth:
         text = f'{timestamp}{method}{path}'.encode() + body._value
         signature = hmac.new(secret, text, hashlib.sha256).hexdigest()
         kwargs.update({'data': body})
-        headers.update({'ACCESS-KEY': key, 'ACCESS-TIMESTAMP': timestamp, 'ACCESS-SIGN': signature})
+        headers.update(
+            {'ACCESS-KEY': key, 'ACCESS-TIMESTAMP': timestamp, 'ACCESS-SIGN': signature}
+        )
 
         return args
 
@@ -138,16 +131,21 @@ class Auth:
         path = '/' + '/'.join(url.parts[2:])
         body = JsonPayload(data) if data else FormData(data)()
         timestamp = str(int(time.time() * 1000))
-        text = f'{timestamp}{method}{path}'.encode() + body._value
+        # PUT and DELETE requests do not require payload inclusion
+        if method == "POST":
+            text = f"{timestamp}{method}{path}".encode() + body._value
+        else:
+            text = f"{timestamp}{method}{path}".encode()
         signature = hmac.new(secret, text, hashlib.sha256).hexdigest()
         kwargs.update({'data': body})
-        headers.update({'API-KEY': key, 'API-TIMESTAMP': timestamp, 'API-SIGN': signature})
+        headers.update(
+            {'API-KEY': key, 'API-TIMESTAMP': timestamp, 'API-SIGN': signature}
+        )
 
         return args
 
     @staticmethod
     def liquid(args: Tuple[str, URL], kwargs: Dict[str, Any]) -> Tuple[str, URL]:
-        method: str = args[0]
         url: URL = args[1]
         data: Dict[str, Any] = kwargs['data'] or {}
         headers: CIMultiDict = kwargs['headers']
@@ -157,7 +155,11 @@ class Auth:
         secret: bytes = session.__dict__['_apis'][Hosts.items[url.host].name][1]
 
         json_payload = json.dumps(
-            {'path': url.raw_path_qs, 'nonce': str(int(time.time() * 1000)), 'token_id': key},
+            {
+                'path': url.raw_path_qs,
+                'nonce': str(int(time.time() * 1000)),
+                'token_id': key,
+            },
             separators=(',', ':'),
         ).encode()
         json_header = json.dumps(
@@ -170,9 +172,7 @@ class Auth:
         ]
         signing_input = b'.'.join(segments)
         signature = hmac.new(secret, signing_input, hashlib.sha256).digest()
-        segments.append(
-            base64.urlsafe_b64encode(signature).replace(b'=', b'')
-        )
+        segments.append(base64.urlsafe_b64encode(signature).replace(b'=', b''))
         encoded_string = b'.'.join(segments).decode()
         body = JsonPayload(data) if data else FormData(data)()
         kwargs.update({'data': body})
@@ -200,7 +200,9 @@ class Auth:
             text = nonce.encode() + body._value
         signature = hmac.new(secret, text, hashlib.sha256).hexdigest()
         kwargs.update({'data': body})
-        headers.update({'ACCESS-KEY': key, 'ACCESS-NONCE': nonce, 'ACCESS-SIGNATURE': signature})
+        headers.update(
+            {'ACCESS-KEY': key, 'ACCESS-NONCE': nonce, 'ACCESS-SIGNATURE': signature}
+        )
 
         return args
 
@@ -242,7 +244,36 @@ class Auth:
         message = f'{method}{path}{expires}'.encode() + body._value
         signature = hmac.new(secret, message, hashlib.sha256).hexdigest()
         kwargs.update({'data': body})
-        headers.update({'api-expires': expires, 'api-key': key, 'api-signature': signature})
+        headers.update(
+            {'api-expires': expires, 'api-key': key, 'api-signature': signature}
+        )
+
+        return args
+
+    @staticmethod
+    def phemex(args: Tuple[str, URL], kwargs: Dict[str, Any]) -> Tuple[str, URL]:
+        url: URL = args[1]
+        data: Dict[str, Any] = kwargs['data'] or {}
+        headers: CIMultiDict = kwargs['headers']
+
+        session: aiohttp.ClientSession = kwargs['session']
+        key: str = session.__dict__['_apis'][Hosts.items[url.host].name][0]
+        secret: bytes = session.__dict__['_apis'][Hosts.items[url.host].name][1]
+
+        path = url.raw_path
+        query = url.query_string
+        body = JsonPayload(data) if data else FormData(data)()
+        expiry = str(int(time.time() + 60.0))
+        formula = f'{path}{query}{expiry}'.encode() + body._value
+        signature = hmac.new(secret, formula, hashlib.sha256).hexdigest()
+        kwargs.update({'data': body})
+        headers.update(
+            {
+                'x-phemex-access-token': key,
+                'x-phemex-request-expiry': expiry,
+                'x-phemex-request-signature': signature,
+            }
+        )
 
         return args
 
@@ -255,7 +286,6 @@ class Item:
 
 class Hosts:
     items = {
-        'www.btcmex.com': Item('btcmex', Auth.btcmex),
         'api.bybit.com': Item('bybit', Auth.bybit),
         'api.bytick.com': Item('bybit', Auth.bybit),
         'stream.bybit.com': Item('bybit', Auth.bybit),
@@ -275,7 +305,6 @@ class Hosts:
         'vstream.binance.com': Item('binance', Auth.binance),
         'testnet.binancefuture.com': Item('binance_testnet', Auth.binance),
         'stream.binancefuture.com': Item('binance_testnet', Auth.binance),
-        'testnet.binancefuture.com': Item('binance_testnet', Auth.binance),
         'dstream.binancefuture.com': Item('binance_testnet', Auth.binance),
         'testnet.binanceops.com': Item('binance_testnet', Auth.binance),
         'testnetws.binanceops.com': Item('binance_testnet', Auth.binance),
@@ -286,4 +315,6 @@ class Hosts:
         'ftx.com': Item('ftx', Auth.ftx),
         'www.bitmex.com': Item('bitmex', Auth.bitmex),
         'testnet.bitmex.com': Item('bitmex_testnet', Auth.bitmex),
+        'api.phemex.com': Item('phemex', Auth.phemex),
+        'testnet-api.phemex.com': Item('phemex_testnet', Auth.phemex),
     }
